@@ -1,41 +1,28 @@
 /*
- * Audtool2
- * Copyright (c) 2007 Audacious development team
+ * audtool.h
+ * Copyright 2005-2011 William Pitcock, George Averill, Giacomo Lozito,
+ *                     Yoshiki Yazawa, Matti Hämäläinen, and John Lindgren
  *
  * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are
- * met:
+ * modification, are permitted provided that the following conditions are met:
  *
  * 1. Redistributions of source code must retain the above copyright notice,
- *    this list of conditions and the following disclaimer.
+ *    this list of conditions, and the following disclaimer.
  *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 #ifndef AUDTOOL_H
 #define AUDTOOL_H
 
-#include <mowgli.h>
 #include <audacious/dbus.h>
 
-extern mowgli_error_context_t *e;
 extern DBusGProxy *dbus_proxy;
 
 struct commandhandler {
@@ -43,7 +30,7 @@ struct commandhandler {
 	void (*handler)(gint argc, gchar **argv);
 	gchar *desc;
 	gint args;
-}; 
+};
 
 extern struct commandhandler handlers[];
 
@@ -74,6 +61,8 @@ extern void set_volume(gint, gchar **);
 
 extern void playlist_position(gint, gchar **);
 extern void playlist_advance(gint, gchar **);
+extern void playlist_auto_advance_status(gint, gchar **);
+extern void playlist_auto_advance_toggle(gint, gchar **);
 extern void playlist_reverse(gint, gchar **);
 extern void playlist_length(gint, gchar **);
 extern void playlist_song(gint, gchar **);
@@ -91,8 +80,9 @@ extern void playlist_repeat_status(gint, gchar **);
 extern void playlist_repeat_toggle(gint, gchar **);
 extern void playlist_shuffle_status(gint, gchar **);
 extern void playlist_shuffle_toggle(gint, gchar **);
+void playlist_stop_after_status (gint argc, gchar * * argv);
+void playlist_stop_after_toggle (gint argc, gchar * * argv);
 extern void playlist_tuple_field_data(gint, gchar **argv);
-extern void playlist_show(gint, gchar **);
 extern void playlist_enqueue_to_temp(gint argc, gchar **argv);
 extern void playlist_ins_url_string(gint argc, gchar **argv);
 extern void playlist_title(gint, gchar **);
@@ -124,7 +114,6 @@ extern void show_filebrowser(gint, gchar **);
 extern void shutdown_audacious_server(gint, gchar **);
 extern void show_about_window(gint, gchar **);
 
-extern void activate(gint argc, gchar **argv);
 extern void toggle_aot(gint argc, gchar **argv);
 extern void get_skin(gint argc, gchar **argv);
 extern void set_skin(gint argc, gchar **argv);
@@ -137,7 +126,6 @@ extern void equalizer_set_eq(gint argc, gchar **argv);
 extern void equalizer_set_eq_preamp(gint argc, gchar **argv);
 extern void equalizer_set_eq_band(gint argc, gchar **argv);
 extern void equalizer_active(gint argc, gchar **argv);
-extern void equalizer_show(gint, gchar **);
 
 extern gint check_args_playlist_pos(gint argc, gchar **argv);
 
